import csv
from django.core.management.base import CommandError
from apella.management.utils import ApellaCommand
from apella.models import Position, RegistryMembership


class Command(ApellaCommand):
    help = 'Export position committee to CSV'

    def handle(self, *args, **options):
        if args:
            raise CommandError("Command does not accept any arguments")

        try:
            writer = csv.writer(self.stdout)

            writer.writerow(['Position ID', 'Committee Internal', 'Committee External'])

            positions = Position.objects.all()

            for position in positions:
                internal = []
                external = []

                committee = position.committee.all()
                if committee:
                
                    for professor in committee:
                        if RegistryMembership.objects.filter(
                                professor=professor,
                                registry__department=position.department,
                                registry__type='internal').exists() or \
                                professor.department and \
                                professor.department is position.department:
                            internal.append(professor.user.id)
                        else:
                            external.append(professor.user.id)

                    c_int = "-".join(str(x) for x in internal)
                    c_ext = "-".join(str(x) for x in external)

                    writer.writerow([position.id, c_int, c_ext])

        except Exception as e:
            raise CommandError("An error occurred: {}".format(e))
